@@ -24,11 +24,13 @@
 Main window class for Desktop platform
 '''
 
+from PyQt4.QtCore import SIGNAL, Qt, pyqtSignal, QByteArray
+from PyQt4.QtGui import QMenu, QCursor, QMainWindow, QIcon, QToolBar
 import hivemind.resource as resource
-from PyQt4.QtCore import SIGNAL, Qt
-from PyQt4.QtGui import QMenu, QCursor, QMainWindow, QIcon
+import hivemind.settings as settings
 from hivemind.main_window import MainView, AbstractMainWindow
 from hivemind.attribute import readable
+from hivemind.smartconference.kp import M3_AVAILABLE
 
 
 class DesktopMainView(MainView):
@@ -37,6 +39,8 @@ class DesktopMainView(MainView):
     @author: Andrew Vasilev
     '''
 
+    mapClicked = pyqtSignal()
+
     __MIN_DRAG_PATH = 20
     '''Minimum drag path length for the desktop'''
 
@@ -62,7 +66,7 @@ class DesktopMainView(MainView):
                 self.emit(SIGNAL('itemClicked'), event.button() == Qt.RightButton, item,
                         parent, childLocation)
             if item is None:
-                self.emit(SIGNAL('mapClicked'))
+                self.mapClicked.emit()
 
 
 class DesktopMainWindow(AbstractMainWindow):
@@ -83,8 +87,14 @@ class DesktopMainWindow(AbstractMainWindow):
         self.__contextMenu = self._createContextMenu()
         self._createMainMenu()
         self._createToolBars()
+        self.restoreState(QByteArray.fromHex(settings.get('mainWindowState')))
 
     def setWindowTitle(self, fileName):
+        '''
+        Set title for main window
+        @param fileName: current filename, can be None
+        @type fileName: str
+        '''
         if fileName:
             QMainWindow.setWindowTitle(self, fileName + ' - HiveMind')
         else:
@@ -109,24 +119,8 @@ class DesktopMainWindow(AbstractMainWindow):
         menu.addAction(self._actionBag.openHyperlinkAction)
         return menu
 
-    def _addEllipsesToActionText(self):
-        '''Add ellipses to the text of the actions displaying dialogs'''
-        actionsWithEllipses = [
-                self._actionBag.fileOpenAction, self._actionBag.fileSaveAsAction,
-                self._actionBag.settingsAction, self._actionBag.exportToImageAction,
-                self._actionBag.addNodeAction, self._actionBag.addSiblingNodeBelowAction,
-                self._actionBag.addSiblingNodeAboveAction, self._actionBag.editNodeAction,
-                self._actionBag.editNodeIconsAction, self._actionBag.editLabelAction,
-                self._actionBag.editEdgeAction, self._actionBag.editAffiliationAction,
-                self._actionBag.startClientAction, self._actionBag.networkSettingsAction,
-                self._actionBag.printAction, self._actionBag.findAction,
-                self._actionBag.editHyperlinkAction, self._actionBag.startServiceAction]
-        for action in actionsWithEllipses:
-            action.setText(action.text() + '...')
-
     def _createMainMenu(self):
         '''Create main menu'''
-        self._addEllipsesToActionText()
         menu = self.menuBar().addMenu(self.tr('&File'))
         menu.addAction(self._actionBag.fileNewAction)
         menu.addAction(self._actionBag.fileOpenAction)
@@ -147,7 +141,7 @@ class DesktopMainWindow(AbstractMainWindow):
         menu.addAction(self._actionBag.findAction)
         menu.addSeparator()
         menu.addAction(self._actionBag.settingsAction)
-        menu = self.menuBar().addMenu(self.tr('&Network'))
+        menu = self.menuBar().addMenu(self.tr('&Teamwork'))
         menu.addAction(self._actionBag.startServiceAction)
         menu.addAction(self._actionBag.startClientAction)
         menu.addAction(self._actionBag.editAffiliationAction)
@@ -155,30 +149,45 @@ class DesktopMainWindow(AbstractMainWindow):
         menu.addAction(self._actionBag.disconnectXMPPAction)
         menu.addSeparator()
         menu.addAction(self._actionBag.networkSettingsAction)
-#        menu.addAction(self._actionBag.networkHelpAction)
-        menu = self.menuBar().addMenu(self.tr('SmartConference'))
-        menu.addAction(self._actionBag.startSmartConferenceRobot)
-        menu.addAction(self._actionBag.stopSmartConferenceRobot)
+        if M3_AVAILABLE:
+            menu = self.menuBar().addMenu(self.tr('&SmartConference'))
+            menu.addAction(self._actionBag.startSmartConferenceRobot)
+            menu.addAction(self._actionBag.stopSmartConferenceRobot)
         menu = self.menuBar().addMenu(self.tr('&Help'))
         menu.addAction(self._actionBag.aboutAction)
 
     def _createToolBars(self):
         '''Create tool bar'''
-        toolbar = self.addToolBar(self.tr('File'))
+        toolbar = self._createToolBar(self.tr('File'), 'fileToolbar')
         toolbar.addAction(self._actionBag.fileNewAction)
         toolbar.addAction(self._actionBag.fileOpenAction)
         toolbar.addAction(self._actionBag.fileSaveAction)
         toolbar.addAction(self._actionBag.fileSaveAsAction)
-        toolbar = self.addToolBar(self.tr('Edit'))
+        toolbar = self._createToolBar(self.tr('Edit'), 'editToolbar')
         toolbar.addAction(self._actionBag.undoAction)
         toolbar.addAction(self._actionBag.redoAction)
-        toolbar = self.addToolBar(self.tr('View'))
+        toolbar = self._createToolBar(self.tr('View'), 'viewToolbar')
         toolbar.addAction(self._actionBag.zoomOutAction)
         toolbar.addAction(self._actionBag.zoomInAction)
-        toolbar = self.addToolBar(self.tr('Connection status'))
+        toolbar = self._createToolBar(self.tr('Connection status'),
+                'connectionStatusToolbar')
         toolbar.addAction(self._actionBag.connectionStatusAction)
 
+    def _createToolBar(self, title, objectName):
+        '''Create tool bar and set its title and object name'''
+        toolbar = QToolBar(title, self)
+        self.addToolBar(Qt.LeftToolBarArea, toolbar)
+        toolbar.setObjectName(objectName)
+        return toolbar
+
     def showMenu(self, rightButton, item):
         '''Show the node menu on right button click'''
         if rightButton:
             self.__contextMenu.exec_(QCursor.pos())
+
+    def closeEvent(self, event):
+        '''
+        Close event handler.
+        Saves toolbars and dockwidgets state to the settings file'''
+        settings.set(mainWindowState = self.saveState().toHex())
+        AbstractMainWindow.closeEvent(self, event)
