@@ -31,8 +31,8 @@ from PyQt4.QtGui import QDialog, QMessageBox, QDialogButtonBox, QLabel, QLineEdi
 QVBoxLayout, QFormLayout, QAbstractItemView, QTableView, QHeaderView, QHBoxLayout, \
 QComboBox, QPushButton, QFontComboBox, QAction, QFontDatabase, QColorDialog, QTextCharFormat, \
 QFont, QPalette, QBrush, QTextCursor, QGridLayout, QCheckBox, QGraphicsView, \
-QTabWidget, QWidget, QSpinBox
-from PyQt4.QtCore import SIGNAL, QRegExp, Qt, QSize, SLOT, QCoreApplication, QObject
+QTabWidget, QWidget, QSpinBox, QScrollArea, QToolBar
+from PyQt4.QtCore import SIGNAL, QRegExp, Qt, QSize, QCoreApplication, QObject
 from hivemind.attribute import readable, adaptCallable
 from hivemind.gui_widgets import SearchingTrMixin, SpecialTextEdit, SettingsCreator, \
 ScalingWidget, IconList, IconTable, LineEditBinder, ColorLabel
@@ -70,8 +70,8 @@ class CommonDialog(SearchingTrMixin, QDialog):
         self._buttonBox = QDialogButtonBox()
         self._okButton = self._buttonBox.addButton(QDialogButtonBox.Ok)
         self._cancelButton = self._buttonBox.addButton(QDialogButtonBox.Cancel)
-        QObject.connect(self._buttonBox, SIGNAL('accepted()'), self._accept)
-        QObject.connect(self._buttonBox, SIGNAL('rejected()'), self.close)
+        self._buttonBox.accepted.connect(self._accept)
+        self._buttonBox.rejected.connect(self.close)
 
     def _accept(self):
         '''
@@ -105,15 +105,15 @@ class EditNodeDialog(CommonDialog):
         #pylint: disable = W0201
         # init edit widget
         self._editor = SpecialTextEdit()
-        QObject.connect(self._editor, SIGNAL('accept'), self._accept)
+        self._editor.accept.connect(self._accept)
         # init html widget
         self._htmlEditor = SpecialTextEdit()
         # create font toolbar
         self._comboFont = QFontComboBox()
         self._comboSize = QComboBox()
         self._comboSize.setEditable(True)
-        QObject.connect(self._comboFont, SIGNAL('currentFontChanged(QFont)'), self._buildFont)
-        QObject.connect(self._comboSize, SIGNAL('currentIndexChanged(int)'), self._buildFont)
+        self._comboFont.currentFontChanged[QFont].connect(self._buildFont)
+        self._comboSize.currentIndexChanged[int].connect(self._buildFont)
         # text format actions
         self._boldAction = QAction(self)
         self._boldAction.setCheckable(True)
@@ -136,17 +136,16 @@ class EditNodeDialog(CommonDialog):
         # edit hyperlink dialog action
         self._editHyperlinkAction = QAction(self)
         # actions signals connection
-        QObject.connect(self._boldAction, SIGNAL('triggered(bool)'), self._setBold)
-        QObject.connect(self._italicAction, SIGNAL('triggered(bool)'), self._setItalic)
-        QObject.connect(self._underlineAction, SIGNAL('triggered(bool)'), self._setUnderline)
-        QObject.connect(self._colorAction, SIGNAL('triggered()'), self._textColor)
-        QObject.connect(self._backgroundAction, SIGNAL('triggered()'), self._textBackground)
-        QObject.connect(self._textHtmlAction, SIGNAL('triggered()'), self._textHtml)
-        QObject.connect(self._clearFormatAction, SIGNAL('triggered()'), self._clearFormat)
-        QObject.connect(self._textFontAction, SIGNAL('triggered()'), self._textFont)
-        QObject.connect(self._editHyperlinkAction, SIGNAL('triggered()'), self._editHyperlink)
-        QObject.connect(self._editor, SIGNAL('currentCharFormatChanged(QTextCharFormat)'),
-                             self._currentCharFormatChanged)
+        self._boldAction.triggered.connect(self._setBold)
+        self._italicAction.triggered.connect(self._setItalic)
+        self._underlineAction.triggered.connect(self._setUnderline)
+        self._colorAction.triggered.connect(self._textColor)
+        self._backgroundAction.triggered.connect(self._textBackground)
+        self._textHtmlAction.triggered.connect(self._textHtml)
+        self._clearFormatAction.triggered.connect(self._clearFormat)
+        self._textFontAction.triggered.connect(self._textFont)
+        self._editHyperlinkAction.triggered.connect(self._editHyperlink)
+        self._editor.currentCharFormatChanged.connect(self._currentCharFormatChanged)
 
     def _currentCharFormatChanged(self, textFormat):
         '''
@@ -184,12 +183,12 @@ class EditNodeDialog(CommonDialog):
         storeAttrs = {}
         if self._isHtml:
             if self._isHtmlSourceMode:
-                storeAttrs['html'] = self._htmlEditor.toPlainText()
+                storeAttrs['html'] = unicode(self._htmlEditor.toPlainText())
             else:
-                storeAttrs['html'] = self._editor.toHtml()
+                storeAttrs['html'] = unicode(self._editor.toHtml())
         else:
             storeAttrs['font'] = self.__node.font
-            storeAttrs['text'] = self._editor.toPlainText()
+            storeAttrs['text'] = unicode(self._editor.toPlainText())
         storeAttrs['color'] = self.__node.color
         storeAttrs['backgroundColor'] = self.__node.backgroundColor
         storeAttrs['propagateNodeFormatting'] = self._propagateFormatting.isChecked()
@@ -394,8 +393,8 @@ class FontDialog(CommonDialog):
         layout.addWidget(scalingWidget, 1, 0, 1, 4)
         layout.addWidget(self._buttonBox, 2, 0, 1, 4)
         self.setLayout(layout)
-        QObject.connect(self.__comboFont, SIGNAL('currentFontChanged(QFont)'), self._setLabelFont)
-        QObject.connect(self.__comboSize, SIGNAL('currentIndexChanged(int)'), self._setLabelSize)
+        self.__comboFont.currentFontChanged.connect(self._setLabelFont)
+        self.__comboSize.currentIndexChanged.connect(self._setLabelSize)
         self._setLabelFormat()
 
     def _accept(self):
@@ -458,31 +457,57 @@ class EditLabelDialog(CommonDialog):
         self._underlineAction.setCheckable(True)
         self._comboFont = QFontComboBox()
         self._comboSize = QComboBox()
-        QObject.connect(self._editor, SIGNAL('accept'), self._accept)
-        QObject.connect(self._comboFont, SIGNAL('currentFontChanged(QFont)'), self._setFont)
-        QObject.connect(self._comboSize, SIGNAL('currentIndexChanged(int)'), self._setSize)
+        self._editor.accept.connect(self._accept)
+        self._comboFont.currentFontChanged.connect(self._setFont)
+        self._comboSize.currentIndexChanged.connect(self._setSize)
         self._parentColor = QCheckBox(self.tr("Parent's color"))
         self._colorButton = QPushButton(self.tr('Choose color'))
         self._parentFont = QCheckBox(self.tr("Parent's font"))
         self._propagateFormatting = QCheckBox(self.tr('Propagate formatting to child nodes'))
-        QObject.connect(self._boldAction, SIGNAL('triggered(bool)'), self._setBold)
-        QObject.connect(self._italicAction, SIGNAL('triggered(bool)'), self._setItalic)
-        QObject.connect(self._underlineAction, SIGNAL('triggered(bool)'), self._setUnderline)
-        QObject.connect(self._colorButton, SIGNAL('clicked()'), self._textColor)
-        QObject.connect(self._parentColor, SIGNAL('toggled(bool)'), self._colorButton,
-                                  SLOT('setDisabled(bool)'))
-        QObject.connect(self._parentColor, SIGNAL('toggled(bool)'), self._updateEditor)
-        QObject.connect(self._parentFont, SIGNAL('toggled(bool)'), self._comboFont,
-                                 SLOT('setDisabled(bool)'))
-        QObject.connect(self._parentFont, SIGNAL('toggled(bool)'), self._comboSize,
-                                 SLOT('setDisabled(bool)'))
-        QObject.connect(self._parentFont, SIGNAL('toggled(bool)'), self._boldAction,
-                                 SLOT('setDisabled(bool)'))
-        QObject.connect(self._parentFont, SIGNAL('toggled(bool)'), self._italicAction,
-                                 SLOT('setDisabled(bool)'))
-        QObject.connect(self._parentFont, SIGNAL('toggled(bool)'), self._underlineAction,
-                                 SLOT('setDisabled(bool)'))
-        QObject.connect(self._parentFont, SIGNAL('toggled(bool)'), self._updateEditor)
+        self._boldAction.triggered.connect(self._setBold)
+        self._italicAction.triggered.connect(self._setItalic)
+        self._underlineAction.triggered.connect(self._setUnderline)
+        self._colorButton.clicked.connect(self._textColor)
+        self._parentColor.toggled.connect(self._colorButton.setDisabled)
+        self._parentColor.toggled.connect(self._updateEditor)
+        self._parentFont.toggled.connect(self._comboFont.setDisabled)
+        self._parentFont.toggled.connect(self._comboSize.setDisabled)
+        self._parentFont.toggled.connect(self._boldAction.setDisabled)
+        self._parentFont.toggled.connect(self._italicAction.setDisabled)
+        self._parentFont.toggled.connect(self._underlineAction.setDisabled)
+        self._parentFont.toggled.connect(self._updateEditor)
+
+    def _layoutComponents(self, centralWidget):
+        '''
+        Layout components of the dialog
+        @param centralWidget: widget to be placed as central widget
+        @type centralWidget: QWidget
+        '''
+        toolbar = QToolBar(self)
+        toolbar.addAction(self._boldAction)
+        toolbar.addAction(self._italicAction)
+        toolbar.addAction(self._underlineAction)
+        secondaryLayout = QHBoxLayout()
+        secondaryLayout.addWidget(self._parentFont)
+        secondaryLayout.addSpacing(20)
+        secondaryLayout.addWidget(self._parentColor)
+        secondaryLayout.addWidget(self._colorButton)
+        mainLayout = QGridLayout()
+        mainLayout.addWidget(toolbar, 0, 0, 1, 2)
+        mainLayout.addWidget(self._comboFont, 0, 2, 1, 5)
+        mainLayout.addWidget(self._comboSize, 0, 7, 1, 3)
+        mainLayout.addWidget(centralWidget, 1, 0, 1, 10)
+        mainLayout.addLayout(secondaryLayout, 2, 0, 1, 10)
+        bottomLayout = QHBoxLayout()
+        bottomLayout.addWidget(self._propagateFormatting)
+        bottomLayout.addStretch()
+        bottomLayout.addWidget(self._buttonBox)
+        mainLayout.addLayout(bottomLayout, 3, 0, 1, 10)
+        self.setLayout(mainLayout)
+        self._editor.setFocus()
+        QWidget.setTabOrder(self._editor, self._buttonBox)
+        QWidget.setTabOrder(self._buttonBox, self._comboFont)
+        QWidget.setTabOrder(self._comboFont, self._comboSize)
 
     def _initEditor(self):
         '''Initialize editor'''
@@ -728,10 +753,12 @@ class AboutDialog(CommonDialog):
         '''
         CommonDialog.__init__(self, parent)
         self.setWindowTitle(self.tr('About HiveMind'))
+        self._initializeCommonStrings()
         self._createComponents()
+        self._initComponents()
 
-    def _createComponents(self):
-        '''Create components'''
+    def _initializeCommonStrings(self):
+        '''Initialize hashes containing all the necessary information'''
         #pylint: disable = W0201
         self._logo = QLabel()
         self._logoImage = resource.getImage('logo')
@@ -741,7 +768,8 @@ class AboutDialog(CommonDialog):
         self._authorInfo = {'AndreyGolovchenko': {'name': self.tr('Andrey Golovchenko'),
                 'site': 'mailto:golovchenkoaa@gmail.com', 'role': self.tr('developer')},
                 'AndreyVasilev': {'name': self.tr('Andrey Vasilev'),
-                'site': 'mailto:vamonster@gmail.com', 'role': self.tr('project leader/designer')},
+                'site': 'mailto:vamonster@gmail.com', 'role':
+                self.tr('project leader/designer')},
                 'AlexanderKulikov': {'name': self.tr('Alexander Kulikov'),
                 'site': 'mailto:asgard1988@yandex.ru', 'role': self.tr('developer')},
                 'OlegKandaurov': {'name': self.tr('Oleg Kandaurov'),
@@ -763,8 +791,8 @@ class AboutDialog(CommonDialog):
         self._linkTemplate = '<a href="%s">%s</a>'
         self._copyright = '%s &copy; 2010-2011 %s' % (unicode(self.tr('Copyright')),
                 unicode(self.tr('%s developers')) % self._appName)
-        self._license = unicode(self.tr('License: %s')) % (self._linkTemplate % (self._licenseLink,
-                self._licenseInfo))
+        self._license = unicode(self.tr('License: %s')) % (self._linkTemplate %
+                (self._licenseLink, self._licenseInfo))
         self._development = unicode(self.tr('%s development is supported by')) % self._appName
 
 
@@ -789,6 +817,23 @@ class EditEdgeDialog(CommonDialog):
         self._createComponents()
         self._initEditor()
 
+    def _initComponents(self):
+        '''Form initialization'''
+        colorLayout = QHBoxLayout()
+        colorLayout.addWidget(self._parentColor)
+        colorLayout.addWidget(self._colorLabel)
+        colorLayout.addWidget(self._colorButton)
+        mainLayout = QGridLayout()
+        mainLayout.addWidget(self._widthLabel, 0, 0)
+        mainLayout.addWidget(self._styleLabel, 0, 1)
+        mainLayout.addWidget(self._edgeWidthComboBox, 1, 0)
+        mainLayout.addWidget(self._edgeStyleComboBox, 1, 1)
+        mainLayout.addWidget(self._nodeStyleLabel, 2, 0, 1, 2)
+        mainLayout.addWidget(self._nodeStyleComboBox, 3, 0, 1, 2)
+        mainLayout.addLayout(colorLayout, 4, 0, 1, 2)
+        mainLayout.addWidget(self._buttonBox, 5, 0, 1, 2)
+        self.setLayout(mainLayout)
+
     def _createComponents(self):
         '''Create components'''
         #pylint: disable = W0201
@@ -819,8 +864,8 @@ class EditEdgeDialog(CommonDialog):
         self._colorLabel = QLabel(self.tr('Color'))
         self._parentColor = QCheckBox(self.tr('Parent'))
         self._colorButton = QPushButton(self.tr('Choose color'))
-        QObject.connect(self._colorButton, SIGNAL('clicked()'), self._edgeColor)
-        QObject.connect(self._parentColor, SIGNAL('toggled(bool)'), self._setParentColor)
+        self._colorButton.clicked.connect(self._edgeColor)
+        self._parentColor.toggled.connect(self._setParentColor)
         self._colorLabel = ColorLabel()
 
     def _initEditor(self):
@@ -871,11 +916,11 @@ class EditEdgeDialog(CommonDialog):
         modified = {}
         modified['edgeColor'] = self.__node.edgeColor
         data = self._edgeWidthComboBox.itemData(self._edgeWidthComboBox.currentIndex())
-        modified['edgeWidth'] = data.toInt()[0] if data.isNull() else None
+        modified['edgeWidth'] = data.toInt()[0] if not data.isNull() else None
         data = self._edgeStyleComboBox.itemData(self._edgeStyleComboBox.currentIndex())
-        modified['edgeStyle'] = unicode(data.toString()) if data.isNull() else None
+        modified['edgeStyle'] = unicode(data.toString()) if not data.isNull() else None
         data = self._nodeStyleComboBox.itemData(self._nodeStyleComboBox.currentIndex())
-        modified['style'] = unicode(data.toString()) if data.isNull() else None
+        modified['style'] = unicode(data.toString()) if not data.isNull() else None
         self.__newAttributes = modified
         QDialog.accept(self)
 
@@ -899,7 +944,39 @@ class SettingsDialog(CommonDialog):
         '''
         CommonDialog.__init__(self, parent)
         self.setWindowTitle(self.tr('Settings'))
-        self._newSettings = list()
+        self._settings = []
+        self._createComponents()
+
+    def _createComponents(self):
+        '''Create components'''
+        #pylint: disable = W0201
+        self._tabWidget = QTabWidget()
+        mainLayout = QVBoxLayout()
+        mainLayout.addWidget(self._tabWidget)
+        mainLayout.addWidget(self._buttonBox)
+        self.setLayout(mainLayout)
+
+    def _createTab(self, name, settingsNames, scrollbar = False):
+        '''
+        Create settings tab
+        @param name: Tab name
+        @type name: string
+        @param settinsNames: list of settings names
+        @type settingsNames: list
+        @param scrollbar: use scroll bar or not
+        @type scrollbar: boolean
+        '''
+        settingsGroup = SettingsCreator(settingsNames)
+        self._settings.append(settingsGroup)
+        settingsWidget = QWidget()
+        settingsWidget.setLayout(settingsGroup.getLayout())
+        if scrollbar:
+            scrollArea = QScrollArea()
+            scrollArea.setWidgetResizable(True)
+            scrollArea.setWidget(settingsWidget)
+            self._tabWidget.addTab(scrollArea, name)
+        else:
+            self._tabWidget.addTab(settingsWidget, name)
 
     def _accept(self):
         '''
@@ -907,8 +984,8 @@ class SettingsDialog(CommonDialog):
         '''
         oldLocale = settings.get('locale')
         newSettings = {}
-        for group in self._newSettings:
-            for setting in group:
+        for settingsGroup in self._settings:
+            for setting in settingsGroup.retrieve():
                 if setting: newSettings.update(setting)
         settings.set(**newSettings)
         if oldLocale != settings.get('locale'):
@@ -944,8 +1021,8 @@ class SideSelectionDialog(CommonDialog):
         self.__label = QLabel(self.tr('Select node position'))
         self.__left = QPushButton(self.tr('Left'))
         self.__right = QPushButton(self.tr('Right'))
-        QObject.connect(self.__left, SIGNAL('clicked()'), self._accept)
-        QObject.connect(self.__right, SIGNAL('clicked()'), self._accept)
+        self.__left.clicked.connect(self._accept)
+        self.__right.clicked.connect(self._accept)
 
     def _initComponents(self):
         '''
@@ -1000,8 +1077,7 @@ class AffiliationDialog(CommonDialog):
         for data, name in self.__model.mapAffiliations.iteritems():
             self.__affiliationCombo.addItem(name, data)
         self.__additionButton = QPushButton(self.tr('Add participant'))
-        QObject.connect(self.__additionButton, SIGNAL('clicked()'),
-                self._addParticipant)
+        self.__additionButton.clicked.connect(self._addParticipant)
 
     def _initComponents(self):
         '''Initialize components'''
@@ -1130,7 +1206,7 @@ class NetworkClientDialog(CommonDialog):
         self.__serviceBinder = LineEditBinder('serviceJid', settings.get('serviceJid'),
                 QRegExp(VALID_JID))
         self.__serviceLabel = QLabel(self.tr('Service JID:'))
-        QObject.connect(self.__view, SIGNAL('clicked()'), self._itemClicked)
+        self.__view.clicked.connect(self._itemClicked)
 
     def _initComponents(self):
         '''Create components'''
@@ -1145,7 +1221,7 @@ class NetworkClientDialog(CommonDialog):
 
     def _itemClicked(self, modelIndex):
         '''Process clicked signal from view'''
-        self.__serviceBinder.setText(modelIndex.data(Qt.EditRole))
+        self.__serviceBinder.setText(modelIndex.data(Qt.EditRole).toString())
 
     def _accept(self):
         '''Hide the dialog, update attributes'''
@@ -1197,8 +1273,7 @@ class NetworkConnectionDialog(CommonDialog):
     def _initComponents(self):
         '''Create components'''
         tabWidget = QTabWidget()
-        QObject.connect(tabWidget, SIGNAL('currentChanged()'),
-                self._adjustConnectionSettings)
+        tabWidget.currentChanged.connect(self._adjustConnectionSettings)
         mainLayout = QVBoxLayout()
         credentialsFormLayout = QFormLayout()
         credentialsFormLayout.addRow(self.__userLabel, self.__userBinder)
