@@ -25,13 +25,13 @@ View delegates for core objects
 '''
 
 import math
-from PyQt4.QtCore import SIGNAL, QRectF, QPointF, Qt, QObject
+from PyQt4.QtCore import QRectF, QPointF, Qt, QObject, pyqtSignal
 from PyQt4.QtGui import QGraphicsScene, QGraphicsItem, QAction, QPen, \
 QPainterPath, QPolygonF, QIcon, QTextDocument
 import hivemind.resource as resource
 import hivemind.settings as settings
 from hivemind.attribute import readable, writable
-from hivemind.core import MindMap
+from hivemind.core import MindMap, Node
 
 class MindMapDelegate(QGraphicsScene):
     '''
@@ -47,6 +47,10 @@ class MindMapDelegate(QGraphicsScene):
     readable('rootDelegate', 'mindMap')
     writable('currentLayerDepth')
 
+    mapChanged = pyqtSignal()
+    curMapChanged = pyqtSignal()
+    currentNodeChanged = pyqtSignal(Node)
+
     def _getCurrentNode(self):
         '''Get current node'''
         return self.__currentNode
@@ -64,7 +68,7 @@ class MindMapDelegate(QGraphicsScene):
         delegate.selected = True
         delegate.ensureVisible(delegate.textBoundingRect())
         self.__currentLayerDepth = currentNode.depth()
-        self.emit(SIGNAL('currentNodeChanged'), self.__currentNode)
+        self.currentNodeChanged.emit(self.__currentNode)
 
     currentNode = property(_getCurrentNode, _setCurrentNode, None, 'Current node')
 
@@ -103,7 +107,7 @@ class MindMapDelegate(QGraphicsScene):
         action = QAction(text, self)
         if shortcut: action.setShortcut(shortcut)
         if icon: action.setIcon(QIcon.fromTheme(icon))
-        if handler: QObject.connect(action, SIGNAL('triggered()'), handler)
+        if handler: action.triggered.connect(handler)
         return action
 
     def addNodeDelegate(self, node):
@@ -160,8 +164,9 @@ class MindMapDelegate(QGraphicsScene):
         '''
         notifyType = args.get('type')
         self.__signalHandlers.get(notifyType)(*values)
-        if notifyType in ['childNodeAdded', 'childNodeRemoved', 'nodeMoved', 'inheritedAttributeChanged']:
-            self.emit(SIGNAL('curMapChanged'))
+        if notifyType in ['childNodeAdded', 'childNodeRemoved', 'nodeMoved',
+                'inheritedAttributeChanged']:
+            self.curMapChanged.emit()
 
     def removeNodeDelegate(self, node):
         '''
@@ -222,7 +227,7 @@ class MindMapDelegate(QGraphicsScene):
         self.positionNodes()
         self.currentNode = mindMap.root
         self.__currentLayerDepth = 0
-        self.emit(SIGNAL('mapChanged'))
+        self.mapChanged.emit()
 
     _MAP_MARGIN_WIDTH = 300
     ''' Width of mind map margin '''
@@ -1135,6 +1140,9 @@ class NodeFinder(QObject):
     Node finder
     @author: Eldar Mamedov
     '''
+
+    statusChanged = pyqtSignal(str)
+
     def __init__(self, controller):
         '''
         @type controller: MainWindowController
@@ -1146,8 +1154,8 @@ class NodeFinder(QObject):
         self.__findText = None
         self.__caseSensitive = False
         self.__highlight = False
-        QObject.connect(controller.mindMapScene, SIGNAL('curMapChanged'), self.refresh)
-        QObject.connect(controller.mindMapScene, SIGNAL('mapChanged'), self.refresh)
+        controller.mindMapScene.curMapChanged.connect(self.refresh)
+        controller.mindMapScene.mapChanged.connect(self.refresh)
 
     def prevFoundNode(self):
         '''
@@ -1244,14 +1252,14 @@ class NodeFinder(QObject):
         Generates signal about status
         '''
         if not len(self.__foundNodes):
-            self.emit(SIGNAL('statusChanged'), 'not_found')
+            self.statusChanged.emit('not_found')
             return
         else:
             if self.__index == len(self.__foundNodes) - 1:
-                self.emit(SIGNAL('statusChanged'), 'last')
+                self.statusChanged.emit('last')
                 return
             if self.__index == 0:
-                self.emit(SIGNAL('statusChanged'), 'first')
+                self.statusChanged.emit('first')
                 return
-        self.emit(SIGNAL('statusChanged'), 'none')
+        self.statusChanged.emit('none')
 
