@@ -191,21 +191,21 @@ def createEditHyperlinkDialog(node, curdir):
     '''
     return EditHyperlinkDialog(node, curdir, __defaultParent)
 
-def invokeSaveFileDialog(title, baseDirectory, filter, selectedFilter):
+def invokeSaveFileDialog(title, baseDirectory, fileFilter, selectedFilter):
     '''
     Factory for creating save file dialog
     @param title: dialog title
     @type title: str
     @param baseDirectory: base save file directory
     @type baseDirectory: str
-    @param filter: file type filter
-    @type filter: str
-    @param selectedFilter: default filter selected, may be None
+    @param fileFilter: file type fileFilter
+    @type fileFilter: str
+    @param selectedFilter: default fileFilter selected, may be None
     @type selectedFilter: str
-    @return: selected file name and active filter
+    @return: selected file name and active fileFilter
     @rtype: [QString, QString]
     '''
     if sysconfig.PLATFORM == 'maemo':
         baseDirectory = '/'
-    return QFileDialog.getSaveFileNameAndFilter(defaultParent(), title, baseDirectory, filter,
-            selectedFilter)
+    return QFileDialog.getSaveFileNameAndFilter(defaultParent(), title, baseDirectory,
+            fileFilter, selectedFilter)
