@@ -39,7 +39,7 @@ import os
 import re
 from twisted.python import log
 from PyQt4.QtGui import QActionGroup, QGraphicsBlurEffect, QMessageBox, QUndoStack, \
-QFileDialog, QPixmap, QPainter, QAction, QDesktopServices, QPrintDialog, QPrinter
+QFileDialog, QPixmap, QPainter, QAction, QDesktopServices, QPrintDialog, QPrinter, QUndoCommand
 from PyQt4.QtCore import QObject, SIGNAL, QTimer, QLocale, QTranslator, QLibraryInfo, \
 Qt, QRectF, QUrl
 import hivemind.gui_factory as gui_factory
@@ -49,7 +49,7 @@ import hivemind.sysconfig as sysconfig
 from hivemind.action_bag import ActionBag
 from hivemind.attribute import writable, adaptCallable
 from hivemind.commands import AddNodeCommand, StateModificationCommand, RemoveNodeCommand, \
-MoveNodeCommand, ActionCommand, CurrentNodeCommand, HivemindCommand
+MoveNodeCommand, ActionCommand, CurrentNodeCommand
 from hivemind.core import MindMap
 from hivemind.gui_delegates import MindMapDelegate, NodeLocation
 from hivemind.gui_widgets import readable
@@ -75,22 +75,28 @@ class MainWindowController(QObject):
         QObject.__init__(self)
         '''Init widgets and configure application'''
         self.__findWidget = None
+        self.__movingNode = None
+        self.__widthActions = None
+        self.__styleActions = None
         self.__actionBag = ActionBag(self)
         self.__mode = self.MODE_NORMAL
         self._createActions()
         self._createStateModificationActions()
         self.__mindMapScene = MindMapDelegate(self.__actionBag)
-        QObject.connect(self.__mindMapScene, SIGNAL('currentNodeChanged'),
-                     adaptCallable(self._setActionsState))
+        self.__mindMapScene.currentNodeChanged.connect(adaptCallable(self._setActionsState))
         self.__mainWindow = gui_factory.createMainWindow(self.__actionBag, self.__mindMapScene)
         self.__mindMapController = MindMapController(self.__mindMapScene, self.__actionBag)
         self.__networkController = network_core.NetworkController(
                 self.__mindMapController, self.__actionBag)
-        self.__smartConferenceRobot = SmartConferenceRobot(self.__mindMapScene)
-        QObject.connect(self.__actionBag.startSmartConferenceRobot, SIGNAL('triggered()'), self.__smartConferenceRobot.start)
-        QObject.connect(self.__actionBag.stopSmartConferenceRobot, SIGNAL('triggered()'), self.__smartConferenceRobot.stop)
-        QObject.connect(self.__mainWindow.mindMapView, SIGNAL('itemClicked'), adaptCallable(self.onItemClicked))
-        QObject.connect(self.__mainWindow, SIGNAL('closeEvent'), self._closeEvent)
+        self.__smartConferenceRobot = SmartConferenceRobot(self.__mindMapScene,
+                self.__networkController)
+        self.__actionBag.startSmartConferenceRobot.triggered.connect(
+                self.__smartConferenceRobot.start)
+        self.__actionBag.stopSmartConferenceRobot.triggered.connect(
+                self.__smartConferenceRobot.stop)
+        QObject.connect(self.__mainWindow.mindMapView, SIGNAL('itemClicked'),
+                adaptCallable(self.onItemClicked))
+        self.__mainWindow.closeEvnt.connect(self._closeEvent)
         _configureApplication(self.__mindMapController)
         self.__mainWindow.showMaximized()
 
@@ -137,9 +143,10 @@ class MainWindowController(QObject):
         @type checkable: bool
         '''
         def handler():
+            '''Action trigger handler, sends state modification command'''
             self.createStateModificationCommand(
                     self.__mindMapScene.currentNode, alteredAttributes)
-        QObject.connect(action, SIGNAL('triggered()'), handler)
+        action.triggered.connect(handler)
         action.setCheckable(checkable)
 
     def _createStateModificationActions(self):
@@ -186,29 +193,31 @@ class MainWindowController(QObject):
 
     def _createActions(self):
         '''Create actions'''
-        QObject.connect(self.__actionBag.editEdgeAction, SIGNAL('triggered()'), self.editEdge)
-        QObject.connect(self.__actionBag.editLabelAction, SIGNAL('triggered()'), self.editLabel)
-        QObject.connect(self.__actionBag.editNodeAction, SIGNAL('triggered()'), self.editNode)
-        QObject.connect(self.__actionBag.editNodeIconsAction, SIGNAL('triggered()'), self.editNodeIcons)
+        self.__actionBag.editEdgeAction.triggered.connect(self.editEdge)
+        self.__actionBag.editLabelAction.triggered.connect(self.editLabel)
+        self.__actionBag.editNodeAction.triggered.connect(self.editNode)
+        self.__actionBag.editNodeIconsAction.triggered.connect(self.editNodeIcons)
         QObject.connect(self.__actionBag.foldNodeAction, SIGNAL('triggered()'), self.foldNode)
-        QObject.connect(self.__actionBag.addNodeAction, SIGNAL('triggered()'), self.addNode)
-        QObject.connect(self.__actionBag.addSiblingNodeBelowAction, SIGNAL('triggered()'), self._addSiblingNodeBelowAction)
-        QObject.connect(self.__actionBag.addSiblingNodeAboveAction, SIGNAL('triggered()'), self._addSiblingNodeAboveAction)
-        QObject.connect(self.__actionBag.removeNodeAction, SIGNAL('triggered()'), self.removeNode)
-        QObject.connect(self.__actionBag.enterTransferModeAction, SIGNAL('triggered()'), self._startNodeMoving)
-        QObject.connect(self.__actionBag.cancelTransferModeAction, SIGNAL('triggered()'), self._cancelNodeMoving)
-        QObject.connect(self.__actionBag.putNodeAction, SIGNAL('triggered()'), self._putNode)
-        QObject.connect(self.__actionBag.putNodeBelowAction, SIGNAL('triggered()'), self._putNodeBelow)
-        QObject.connect(self.__actionBag.putNodeAboveAction, SIGNAL('triggered()'), self._putNodeAbove)
-        QObject.connect(self.__actionBag.undoAction, SIGNAL('triggered()'), self._doUndo)
-        QObject.connect(self.__actionBag.redoAction, SIGNAL('triggered()'), self._doRedo)
-        QObject.connect(self.__actionBag.aboutAction, SIGNAL('triggered()'), self.onAbout)
-        QObject.connect(self.__actionBag.exitAction, SIGNAL('triggered()'), self._closeMainWindow)
-        QObject.connect(self.__actionBag.settingsAction, SIGNAL('triggered()'), self.onSettings)
-        QObject.connect(self.__actionBag.findAction, SIGNAL('triggered()'), self.onFind)
-        QObject.connect(self.__actionBag.showContextMenuAction, SIGNAL('triggered()'), self._virtualClick)
-        QObject.connect(self.__actionBag.editHyperlinkAction, SIGNAL('triggered()'), self.editHyperlink)
-        QObject.connect(self.__actionBag.openHyperlinkAction, SIGNAL('triggered()'), self.openHyperlink)
+        self.__actionBag.addNodeAction.triggered.connect(self.addNode)
+        self.__actionBag.addSiblingNodeBelowAction.triggered.connect(
+                self._addSiblingNodeBelowAction)
+        self.__actionBag.addSiblingNodeAboveAction.triggered.connect(
+                self._addSiblingNodeAboveAction)
+        self.__actionBag.removeNodeAction.triggered.connect(self.removeNode)
+        self.__actionBag.enterTransferModeAction.triggered.connect(self._startNodeMoving)
+        self.__actionBag.cancelTransferModeAction.triggered.connect(self._cancelNodeMoving)
+        self.__actionBag.putNodeAction.triggered.connect(self._putNode)
+        self.__actionBag.putNodeBelowAction.triggered.connect(self._putNodeBelow)
+        self.__actionBag.putNodeAboveAction.triggered.connect(self._putNodeAbove)
+        self.__actionBag.undoAction.triggered.connect(self._doUndo)
+        self.__actionBag.redoAction.triggered.connect(self._doRedo)
+        self.__actionBag.aboutAction.triggered.connect(self.onAbout)
+        self.__actionBag.exitAction.triggered.connect(self._closeMainWindow)
+        self.__actionBag.settingsAction.triggered.connect(self.onSettings)
+        self.__actionBag.findAction.triggered.connect(self.onFind)
+        self.__actionBag.showContextMenuAction.triggered.connect(self._virtualClick)
+        self.__actionBag.editHyperlinkAction.triggered.connect(self.editHyperlink)
+        self.__actionBag.openHyperlinkAction.triggered.connect(self.openHyperlink)
 
     def _doUndo(self):
         '''
@@ -252,6 +261,7 @@ class MainWindowController(QObject):
         '''
         initialAttributeValues = node.getAttributes(getAll = True)
         def _accept():
+            '''Asynchronous handler of accepted signal of dialog'''
             alteredAttributes = dialog.attributes()
             # need to fix it, must use initialAttributeValues
             unmodifiedAttributes = {}
@@ -260,7 +270,7 @@ class MainWindowController(QObject):
                     unmodifiedAttributes[key] = initialAttributeValues[key]
             self._recordCommand(StateModificationCommand(node, unmodifiedAttributes,
                     alteredAttributes))
-        QObject.connect(dialog, SIGNAL('accepted()'), _accept)
+        dialog.accepted.connect(_accept)
         dialog.exec_()
 
     def _recordCommand(self, command):
@@ -276,6 +286,15 @@ class MainWindowController(QObject):
         self.__mainWindow.showMenu(True, self.__mindMapScene.currentNode)
 
     def onItemClicked(self, rightButton, item, parent, childLocation):
+        '''
+        Handler of item click action
+        @param rightButton: whether user used right button or left
+        @type rightButton: bool 
+        @type item: NodeDelegate
+        @type parent: NodeDelegate
+        @param childLocation: location of child nodes
+        @type childLocation: int
+        '''
         if item: self._recordCommand(CurrentNodeCommand(item.node))
         if self.__mode == MainWindowController.MODE_NORMAL:
             if item is not None:
@@ -300,7 +319,7 @@ class MainWindowController(QObject):
         newNode = parentNode.createChildPrototype()
         newNode.setAttributes(left = self.__mindMapScene.currentNode.left)
         editor = gui_factory.createEditNodeDialog(newNode)
-        QObject.connect(editor, SIGNAL('accepted()'), _accept)
+        editor.accepted.connect(_accept)
         editor.exec_()
 
     def _addSiblingNodeAboveAction(self):
@@ -316,7 +335,7 @@ class MainWindowController(QObject):
         newNode = parentNode.createChildPrototype()
         newNode.setAttributes(left = self.__mindMapScene.currentNode.left)
         editor = gui_factory.createEditNodeDialog(newNode)
-        QObject.connect(editor, SIGNAL('accepted()'), _accept)
+        editor.accepted.connect(_accept)
         editor.exec_()
 
     def _startNodeMoving(self):
@@ -324,11 +343,11 @@ class MainWindowController(QObject):
         Switch controller and view to transfer mode
         '''
         self.__mode = self.MODE_TRANSFER
-        self.__inactiveEffect = QGraphicsBlurEffect()
-        self.__inactiveEffect.setBlurRadius(3)
+        inactiveEffect = QGraphicsBlurEffect()
+        inactiveEffect.setBlurRadius(3)
         self.__movingNode = self.__mindMapScene.currentNode
         self.__mindMapScene.getDelegate(self.__movingNode) \
-                .setGraphicsEffect(self.__inactiveEffect)
+                .setGraphicsEffect(inactiveEffect)
         self._setActionsState(self.__mindMapScene.currentNode)
 
     def _cancelNodeMoving(self):
@@ -406,15 +425,15 @@ class MainWindowController(QObject):
         if self.__findWidget is None:
             self.__findWidget = gui_factory.createFindToolBar(self)
             if sysconfig.PLATFORM == 'maemo':
-                self.__findWidget.move(self.__mainWindow.width() - self.__findWidget.width() + 10,
-                        self.__mainWindow.height() - self.__findWidget.height() + 10)
+                self.__findWidget.move(self.__mainWindow.width() - self.__findWidget.width() +
+                        10, self.__mainWindow.height() - self.__findWidget.height() + 10)
             else:
                 self.__mainWindow.addToolBar(Qt.BottomToolBarArea, self.__findWidget)
         if self.__findWidget.isVisible():
             self.__findWidget.setVisible(False)
         else:
             self.__findWidget.setVisible(True)
-            self.__findWidget._findLineEdit.setFocus()
+            self.__findWidget.setDefaultFocus()
 
     def editEdge(self):
         '''Edit node's edge decorations and style'''
@@ -480,7 +499,7 @@ class MainWindowController(QObject):
             self._recordCommand(AddNodeCommand(parentNode, childNode))
         childNode = parentNode.createChildPrototype()
         editor = gui_factory.createEditNodeDialog(childNode)
-        QObject.connect(editor, SIGNAL('accepted()'), _accept)
+        editor.accepted.connect(_accept)
         editor.exec_()
 
     def removeNode(self):
@@ -488,6 +507,7 @@ class MainWindowController(QObject):
         Remove selected node
         '''
         def _recordCommand():
+            '''Record node deletion command'''
             self._recordCommand(RemoveNodeCommand(self.__mindMapScene.currentNode))
         if settings.get('confirmDelete'):
             ret = QMessageBox.question(self.__mainWindow, self.tr('Confirm delete'),
@@ -561,22 +581,24 @@ class MindMapController(QObject):
         QObject.__init__(self)
         self.__mindMapScene = mindMapScene
         self.__actionBag = actionBag
+        self.__undoStack = None
+        self.__initialMindMap = None
         self._loadUndoStack(QUndoStack())
         self.__fileName = None
         self.__autosaved = False
         self.__autosaveTimer = QTimer(self)
         self.__autosaveTimer.setSingleShot(False)
-        QObject.connect(self.__autosaveTimer, SIGNAL('timeout()'), self._autosaveMindMap)
+        self.__autosaveTimer.timeout.connect(self._autosaveMindMap)
         settings.connect(self._updateAutosave)
         self._updateAutosave()
-        QObject.connect(self.__actionBag.fileNewAction, SIGNAL('triggered()'), self.onFileNew)
-        QObject.connect(self.__actionBag.fileOpenAction, SIGNAL('triggered()'), self.onFileOpen)
-        QObject.connect(self.__actionBag.fileSaveAction, SIGNAL('triggered()'), self.onFileSave)
-        QObject.connect(self.__actionBag.fileSaveAsAction, SIGNAL('triggered()'), self.onFileSaveAs)
-        QObject.connect(self.__actionBag.exportToImageAction, SIGNAL('triggered()'), self.onExportToImage)
-        QObject.connect(self.__actionBag.printAction, SIGNAL('triggered()'), self.onPrint)
+        self.__actionBag.fileNewAction.triggered.connect(self.onFileNew)
+        self.__actionBag.fileOpenAction.triggered.connect(self.onFileOpen)
+        self.__actionBag.fileSaveAction.triggered.connect(self.onFileSave)
+        self.__actionBag.fileSaveAsAction.triggered.connect(self.onFileSaveAs)
+        self.__actionBag.exportToImageAction.triggered.connect(self.onExportToImage)
+        self.__actionBag.printAction.triggered.connect(self.onPrint)
         for action in self.__actionBag.recentFileActions:
-            QObject.connect(action, SIGNAL('triggered()'), self.openRecentFile)
+            action.triggered.connect(self.openRecentFile)
 
     def _loadUndoStack(self, undoStack):
         '''
@@ -587,9 +609,11 @@ class MindMapController(QObject):
         self.__undoStack = undoStack
         self.__actionBag.undoAction.setEnabled(undoStack.canRedo())
         self.__actionBag.redoAction.setEnabled(undoStack.canUndo())
-        QObject.connect(self.__undoStack, SIGNAL('canUndoChanged(bool)'), adaptCallable(self.__actionBag.undoAction.setEnabled))
-        QObject.connect(self.__undoStack, SIGNAL('canRedoChanged(bool)'), adaptCallable(self.__actionBag.redoAction.setEnabled))
-        QObject.connect(self.__undoStack, SIGNAL('cleanChanged(bool)'), adaptCallable(self._undoStackStateChanged))
+        self.__undoStack.canUndoChanged.connect(adaptCallable(
+                self.__actionBag.undoAction.setEnabled))
+        self.__undoStack.canRedoChanged.connect(adaptCallable(
+                self.__actionBag.redoAction.setEnabled))
+        self.__undoStack.cleanChanged.connect(adaptCallable(self._undoStackStateChanged))
 
     def loadUndoStackFromNetwork(self, stack):
         '''
@@ -626,25 +650,25 @@ class MindMapController(QObject):
         '''
         This method call save dialog and return file name for saving
         @param title: title of the save dialog
-        @type title: QString
-        @param fileTypes: file types for save dialog filter
-        @type fileTypes: hash
+        @fileType title: QString
+        @param fileTypes: file types for save dialog fileFilter
+        @fileType fileTypes: hash
         @return: name of selected file
         @rtype: str
         '''
-        filter = ''
-        for type in fileTypes:
-            filter = filter + type[0] + ';;'
+        fileFilter = ''
+        for fileType in fileTypes:
+            fileFilter = fileFilter + fileType[0] + ';;'
         selectedFilter = fileTypes[0][0]
         fileName, currentFilter = gui_factory.invokeSaveFileDialog(title, self.fileDirectory(),
-                filter, selectedFilter)
+                fileFilter, selectedFilter)
         if len(currentFilter) == 0:
             currentFilter = selectedFilter
         if len(fileName) == 0:
             return None
-        for type in fileTypes:
-            if type[0] == currentFilter:
-                fileType = type
+        for fileType in fileTypes:
+            if fileType[0] == currentFilter:
+                fileType = fileType
                 if not re.match(fileType[1], fileName): fileName += fileType[2]
                 break
         return unicode(fileName)
@@ -654,7 +678,7 @@ class MindMapController(QObject):
         fileTypes = [[self.tr('PNG image (*.png)'), '.*\.png', '.png'],
                 [self.tr('JPEG image (*.jpg *.jpeg)'), '.*\.(jpg|jpeg)', '.jpg'],
                 [self.tr('Windows BMP image (*.bmp)'), '.*\.bmp', '.bmp']]
-        fileName = self._getSaveFileName(self.tr('Save as image'), fileTypes)
+        fileName = self._getSaveFileName(self.tr('Export to image'), fileTypes)
         if not fileName:
             return
         size = self.__mindMapScene.itemsBoundingRect().size()
@@ -732,23 +756,31 @@ class MindMapController(QObject):
                     unicode(args[1]))
             return False
 
-    def executeCommandFromNetwork(self, command):
+    def performCommandFromNetwork(self, command):
         '''
-        Deserialize command and execute it
+        Deserialize, execute and store command received from network
         @param command: serialized command
         @type command: str
         '''
         command = parser.deserializeCommand(command, self.__mindMapScene.mindMap)
         self.executeCommand(command)
+        self.storeCommand(command)
+
+    def storeCommand(self, command):
+        '''
+        Store command in undo stack if possible
+        @param command: command to store
+        '''
+        if isinstance(command, QUndoCommand):
+            self.__undoStack.push(command)
 
     def executeCommand(self, command):
         '''
         Execute command, created outside main controller
         @param command: command to execute
-        @type command: str
         '''
-        if not isinstance(command, HivemindCommand):
-            self.__undoStack.push(command)
+        if isinstance(command, QUndoCommand):
+            command.redo()
         elif isinstance(command, ActionCommand):
             {'undo': self.__undoStack.undo, 'redo': self.__undoStack.redo}[command.action]()
         elif isinstance(command, CurrentNodeCommand):
@@ -841,6 +873,7 @@ class MindMapController(QObject):
         @param path: path to mind map file
         @type path: unicode
         '''
+        #pylint: disable=W0703
         filePath = path
         if self._showRecoverDataDialog(filePath):
             self.__autosaved = True
