@@ -27,13 +27,13 @@ Dialogs for Maemo platform
 import hivemind.resource as resource
 from PyQt4.QtGui import QFrame, QWidget, QGridLayout, QStackedWidget, QVBoxLayout, \
 QRadioButton, QHBoxLayout, QToolBar, QIcon, QPalette, QPushButton, QLabel, \
-QTextBrowser, QTabWidget, QDialog, QFont, QDesktopServices, QScrollArea, \
+QTextBrowser, QDialog, QFont, QDesktopServices, \
 QAction, QPainter, QBrush, QPen, QColor
-from PyQt4.QtCore import Qt, SIGNAL, QSize, QTimer, QUrl, QEvent, QObject
+from PyQt4.QtCore import Qt, QSize, QTimer, QUrl, QEvent
 from hivemind.dialogs import EditNodeDialog, EditLabelDialog, IconDialog, \
 AboutDialog, EditEdgeDialog, SettingsDialog, AffiliationDialog, NetworkSettingsDialog, \
 NetworkClientDialog, NetworkConnectionDialog
-from hivemind.gui_widgets import ScalingWidget, SettingsCreator, ActionImageButton, FindToolBar
+from hivemind.gui_widgets import ScalingWidget, ActionImageButton, FindToolBar
 from hivemind.attribute import adaptCallable
 import hivemind.__version__ as __version__
 
@@ -110,9 +110,8 @@ class MaemoEditNodeDialog(MaemoDialogMixin, EditNodeDialog):
         mainLayout.addLayout(bottomLayout)
         self._editor.setFocus()
         self.setLayout(mainLayout)
-        QObject.connect(self.__showHtml, SIGNAL('toggled(bool)'), adaptCallable(self._changedMode))
-        QObject.connect(self._textHtmlAction, SIGNAL('toggled(bool)'),
-                                     adaptCallable(self._showTextSourceButtons))
+        self.__showHtml.toggled.connect(adaptCallable(self._changedMode))
+        self._textHtmlAction.toggled.connect(adaptCallable(self._showTextSourceButtons))
 
     def _createToolbar(self):
         '''Create editor toolbar'''
@@ -179,36 +178,12 @@ class MaemoEditLabelDialog(MaemoDialogMixin, EditLabelDialog):
     def _initComponents(self):
         '''Form initialization'''
         #create toolbar
-        toolbar = QToolBar(self)
         self._boldAction.setIcon(QIcon(resource.getImage('node_editor_bold')))
-        toolbar.addAction(self._boldAction)
         self._italicAction.setIcon(QIcon(resource.getImage('node_editor_italic')))
-        toolbar.addAction(self._italicAction)
         self._underlineAction.setIcon(QIcon(resource.getImage('node_editor_underline')))
-        toolbar.addAction(self._underlineAction)
-        secondaryLayout = QHBoxLayout()
-        secondaryLayout.addWidget(self._parentFont)
-        secondaryLayout.addSpacing(20)
-        secondaryLayout.addWidget(self._parentColor)
-        secondaryLayout.addWidget(self._colorButton)
-        scalingWidget = ScalingWidget(self._editor, 2.0)
+        centralWidget = ScalingWidget(self._editor, 2.0)
         self._editor.setFrameShape(QFrame.Box)
-        mainLayout = QGridLayout()
-        mainLayout.addWidget(toolbar, 0, 0, 1, 2)
-        mainLayout.addWidget(self._comboFont, 0, 2, 1, 5)
-        mainLayout.addWidget(self._comboSize, 0, 7, 1, 3)
-        mainLayout.addWidget(scalingWidget, 1, 0, 1, 10)
-        mainLayout.addLayout(secondaryLayout, 2, 0, 1, 10)
-        bottomLayout = QHBoxLayout()
-        bottomLayout.addWidget(self._propagateFormatting)
-        bottomLayout.addStretch()
-        bottomLayout.addWidget(self._buttonBox)
-        mainLayout.addLayout(bottomLayout, 3, 0, 1, 10)
-        self.setLayout(mainLayout)
-        self._editor.setFocus()
-        QWidget.setTabOrder(self._editor, self._buttonBox)
-        QWidget.setTabOrder(self._buttonBox, self._comboFont)
-        QWidget.setTabOrder(self._comboFont, self._comboSize)
+        self._layoutComponents(centralWidget)
 
 
 class MaemoIconDialog(MaemoDialogMixin, IconDialog):
@@ -253,13 +228,10 @@ class MaemoAboutDialog(AboutDialog):
     '''
     def __init__(self, parent = None):
         AboutDialog.__init__(self, parent)
-        self._createComponents()
-        self._initComponents()
 
     def _createComponents(self):
         '''Create components'''
         #pylint: disable = W0201
-        AboutDialog._createComponents(self)
         self._logo.setPixmap(self._logoImage)
         self._visitWebsite = QPushButton(self.tr('Visit website'))
         self._reportBug = QPushButton(self.tr('Report bug'))
@@ -281,8 +253,8 @@ class MaemoAboutDialog(AboutDialog):
                 self._generatePartcipantInfo('NicuBuculei'),
                 self._generatePartcipantInfo('Mentalrey')))
         self._about.setOpenExternalLinks(True)
-        QObject.connect(self._visitWebsite, SIGNAL('clicked()'), self._openWebsite)
-        QObject.connect(self._reportBug, SIGNAL('clicked()'), self._openBugReport)
+        self._visitWebsite.clicked.connect(self._openWebsite)
+        self._reportBug.clicked.connect(self._openBugReport)
 
     def _generatePartcipantInfo(self, name):
         '''
@@ -338,23 +310,6 @@ class MaemoEditEdgeDialog(MaemoDialogMixin, EditEdgeDialog):
         MaemoDialogMixin.__init__(self)
         self._initComponents()
 
-    def _initComponents(self):
-        '''Form initialization'''
-        colorLayout = QHBoxLayout()
-        colorLayout.addWidget(self._parentColor)
-        colorLayout.addWidget(self._colorLabel)
-        colorLayout.addWidget(self._colorButton)
-        mainLayout = QGridLayout()
-        mainLayout.addWidget(self._widthLabel, 0, 0)
-        mainLayout.addWidget(self._styleLabel, 0, 1)
-        mainLayout.addWidget(self._edgeWidthComboBox, 1, 0)
-        mainLayout.addWidget(self._edgeStyleComboBox, 1, 1)
-        mainLayout.addWidget(self._nodeStyleLabel, 2, 0, 1, 2)
-        mainLayout.addWidget(self._nodeStyleComboBox, 3, 0, 1, 2)
-        mainLayout.addLayout(colorLayout, 4, 0, 1, 2)
-        mainLayout.addWidget(self._buttonBox, 5, 0, 1, 2)
-        self.setLayout(mainLayout)
-
 
 class MaemoSettingsDialog(MaemoDialogMixin, SettingsDialog):
     '''
@@ -367,58 +322,16 @@ class MaemoSettingsDialog(MaemoDialogMixin, SettingsDialog):
         '''
         SettingsDialog.__init__(self, parent)
         MaemoDialogMixin.__init__(self)
-        tabWidget = QTabWidget()
-        self._general = SettingsCreator(['locale', 'confirmDelete', 'useExtendedMenu',
-                'autosaveEnabled', 'autosaveInterval'])
-        generalTab = QWidget()
-        generalTab.setLayout(self._general.getLayout())
-        generalScrollArea = QScrollArea()
-        generalScrollArea.setWidget(generalTab)
-        generalScrollArea.setWidgetResizable(True)
-        self._node = SettingsCreator(['defaultFont',
-                'defaultNodeTextColor',
-                'defaultNodeBackgroundColor',
-                'defaultSelectedNodeBackgroundColor'])
-        nodeTab = QWidget()
-        nodeTab.setLayout(self._node.getLayout())
-        self._edge = SettingsCreator(['defaultEdgeWidth', 'defaultEdgeColor',
+        self._createTab(self.tr('General'), ['locale', 'confirmDelete', 'useExtendedMenu',
+                'autosaveEnabled', 'autosaveInterval'], True)
+        self._createTab(self.tr('Node'), ['defaultFont', 'defaultNodeTextColor',
+                'defaultNodeBackgroundColor', 'defaultSelectedNodeBackgroundColor'])
+        self._createTab(self.tr('Edge && Label'), ['defaultEdgeWidth', 'defaultEdgeColor',
                 'defaultLabelFont', 'defaultLabelColor'])
-        edgeTab = QWidget()
-        edgeTab.setLayout(self._edge.getLayout())
-        self._view = SettingsCreator(['autoHideNodeMenuTimeout',
+        self._createTab(self.tr('View'), ['autoHideNodeMenuTimeout',
                 'showNodeMenuAnimationDuration', 'hideNodeMenuAnimationDuration',
-                'defaultZoomLevel', 'maxNodeTextWidth'])
-        viewTab = QWidget()
-        viewTab.setLayout(self._view.getLayout())
-        shortcutsTab = QWidget()
-        shortcutsScrollArea = QScrollArea()
-        shortcutsScrollArea.setWidgetResizable(True)
-        self._shortcuts = SettingsCreator(['shortcuts'])
-        shortcutsTab.setLayout(self._shortcuts.getLayout())
-        shortcutsScrollArea.setWidget(shortcutsTab)
-        viewScrollArea = QScrollArea()
-        viewScrollArea.setWidget(viewTab)
-        viewScrollArea.setWidgetResizable(True)
-        tabWidget.addTab(generalScrollArea, self.tr('General'))
-        tabWidget.addTab(nodeTab, self.tr('Node'))
-        tabWidget.addTab(edgeTab, self.tr('Edge && Label'))
-        tabWidget.addTab(viewScrollArea, self.tr('View'))
-        tabWidget.addTab(shortcutsScrollArea, self.tr('Shortcuts'))
-        mainLayout = QVBoxLayout()
-        mainLayout.addWidget(tabWidget)
-        mainLayout.addWidget(self._buttonBox)
-        self.setLayout(mainLayout)
-
-    def _accept(self):
-        '''
-        Retrieve new settings
-        '''
-        self._newSettings.append(self._general.retrieve())
-        self._newSettings.append(self._node.retrieve())
-        self._newSettings.append(self._edge.retrieve())
-        self._newSettings.append(self._view.retrieve())
-        self._newSettings.append(self._shortcuts.retrieve())
-        SettingsDialog._accept(self)
+                'defaultZoomLevel', 'maxNodeTextWidth'], True)
+        self._createTab(self.tr('Shortcuts'), ['shortcuts'], True)
 
 
 class MaemoAffiliationDialog(MaemoDialogMixin, AffiliationDialog):
@@ -527,6 +440,7 @@ class MaemoExtendedMenuDialog(QDialog):
         self.__freezed = False
 
     def reject(self):
+        '''Close dialog with reject state returned'''
         if self.__freezed == False:
             QDialog.reject(self)
 
@@ -536,7 +450,7 @@ class MaemoExtendedMenuDialog(QDialog):
         @type action: QAction
         '''
         button = ActionImageButton(action)
-        QObject.connect(button, SIGNAL('clicked()'), self.accept)
+        button.clicked.connect(self.accept)
         return button
 
 
@@ -589,6 +503,7 @@ class MaemoNetworkMainDialog(MaemoDialogMixin, QDialog):
 
     def _createComponents(self):
         '''Create components'''
+        #pylint: disable = W0201
         self.__editAffiliationButton = QPushButton(self.__bag.editAffiliationAction.text())
         self.__disconnectXMPPButton = QPushButton(self.__bag.disconnectXMPPAction.text())
         self.__stopProtocolButton = QPushButton(self.__bag.stopProtocolAction.text())
@@ -680,9 +595,9 @@ class MaemoFindToolBar(FindToolBar):
         self.__prevAction.setIcon(QIcon(resource.getImage('find_previous')))
         self.__nextAction.setIcon(QIcon(resource.getImage('find_next')))
         self.__closeAction.setIcon(QIcon(resource.getImage('find_close')))
-        QObject.connect(self.__nextAction, SIGNAL('triggered()'), self._finder.nextFoundNode)
-        QObject.connect(self.__prevAction, SIGNAL('triggered()'), self._finder.prevFoundNode)
-        QObject.connect(self.__closeAction, SIGNAL('triggered()'), self.close)
+        self.__nextAction.triggered.connect(self._finder.nextFoundNode)
+        self.__prevAction.triggered.connect(self._finder.prevFoundNode)
+        self.__closeAction.triggered.connect(self.close)
         self.__prevButton = ActionImageButton(self.__prevAction)
         self.__nextButton = ActionImageButton(self.__nextAction)
         self.__closeButton = ActionImageButton(self.__closeAction)
