@@ -24,11 +24,11 @@
 Main window class for Mobile platform
 '''
 
-from PyQt4.QtCore import SIGNAL, Qt, QObject
+from PyQt4.QtCore import SIGNAL, Qt, pyqtSignal
 from PyQt4.QtGui import QAction, QIcon, QMainWindow, QApplication
 from hivemind.main_window import MainView, AbstractMainWindow
 from hivemind.gui_widgets import MaemoSidePanel, FullScreenExitButton, MaemoNodeMenu
-from hivemind.attribute import adaptCallable, readable
+from hivemind.attribute import readable
 import hivemind.settings as settings
 from hivemind.maemo.dialogs import MaemoExtendedMenuDialog, MaemoNetworkMainDialog
 
@@ -39,6 +39,8 @@ class MaemoMainView(MainView):
     @author: Andrew Vasilev
     '''
 
+    mapClicked = pyqtSignal()
+
     __MIN_DRAG_PATH = 50
     '''Minimum drag path length for the Maemo platform'''
 
@@ -64,7 +66,7 @@ class MaemoMainView(MainView):
             if parent is not None:
                 self.emit(SIGNAL('itemClicked'), False, item, parent, childLocation)
             if item is None:
-                self.emit(SIGNAL('mapClicked'))
+                self.mapClicked.emit()
 
 
 class MaemoMainWindow(AbstractMainWindow):
@@ -86,7 +88,7 @@ class MaemoMainWindow(AbstractMainWindow):
         self.__fullScreenAction = QAction(QIcon.fromTheme('view-fullscreen'),
                 self.tr('&Full screen'), self)
         self.__fullScreenExitButton = FullScreenExitButton(self)
-        QObject.connect(self.__fullScreenAction, SIGNAL('triggered()'), self.showFullScreen)
+        self.__fullScreenAction.triggered.connect(self.showFullScreen)
         networkDialog = MaemoNetworkMainDialog(actionBag, self)
         actionBag.connectionStatusAction.triggered.connect(networkDialog.exec_)
         self.__contextMenu = self._createContextMenu()
@@ -108,6 +110,11 @@ class MaemoMainWindow(AbstractMainWindow):
         sidePanel.addAction(self.__actionBag.redoAction)
 
     def setWindowTitle(self, fileName):
+        '''
+        Set new title for the window
+        @param fileName: filename of opened mind map, can be None
+        @type fileName: str
+        '''
         if fileName:
             QMainWindow.setWindowTitle(self, fileName)
         else:
@@ -144,10 +151,8 @@ class MaemoMainWindow(AbstractMainWindow):
         Set event handlers to hide any context menu when it is shown
         and the other menu is requested to show
         '''
-        QObject.connect(self.__contextMenu, SIGNAL('show'),
-                     adaptCallable(self.__additionalContextMenu.hideMenu))
-        QObject.connect(self.__additionalContextMenu, SIGNAL('show'),
-                     adaptCallable(self.__contextMenu.hideMenu))
+        self.__contextMenu.isShowed.connect(self.__additionalContextMenu.hideMenu)
+        self.__additionalContextMenu.isShowed.connect(self.__contextMenu.hideMenu)
 
     def _createMainMenu(self):
         '''Create main menu'''
