@@ -23,8 +23,6 @@
 '''
 Network subsystem of the application
 '''
-from twisted.names.srvconnect import SRVConnector
-
 from idavoll.backend import PubSubServiceFromBackend, BackendService
 from idavoll.memory_storage import Storage, LeafNode
 from wokkel.xmppim import RosterClientProtocol
@@ -36,6 +34,7 @@ from wokkel.subprotocols import StreamManager, XMPPHandler, XMPPHandlerCollectio
 from twisted.words.protocols import jabber
 from twisted.words.xish.xmlstream import STREAM_ERROR_EVENT
 from twisted.words.xish.domish import Element
+from twisted.names.srvconnect import SRVConnector
 from twisted import application
 from twisted.internet.task import LoopingCall
 from twisted.internet import reactor
@@ -50,7 +49,6 @@ import hivemind, uuid, copy, idavoll
 from PyQt4.QtCore import QObject
 #pylint: disable=C0103
 
-
 ''' XMPP PubSub node name '''
 XMPP_NODE_NAME = unicode('HiveMind')
 ''' Time in seconds we must wait for unsubscribe '''
@@ -184,25 +182,15 @@ class NetworkController(QObject):
         Publish command in common space
         @param command: command to publish in shared space
         '''
-        if self.__protocol and self._isPropagationAllowed(command):
-            self.__protocol.proposeChangeset(Changeset(parser.serializeCommand(command),
-                    'command'))
+        if self.__protocol:
+            if _isPropagationAllowed(command):
+                self.__protocol.proposeChangeset(Changeset(parser.serializeCommand(command),
+                        'command'))
+            else:
+                self.__mindMapController.executeCommand(command)
         else:
             self.__mindMapController.executeCommand(command)
-
-    def _isPropagationAllowed(self, command):
-        '''
-        Check if command must be propagated through network or not
-        @param command: command to inspect
-        '''
-        if hivemind.settings.get('presentationMode'):
-            return True
-        if isinstance(command, StateModificationCommand):
-            if 'folded' in command.stateAfter.keys():
-                return False
-        if isinstance(command, CurrentNodeCommand):
-            return False
-        return True
+            self.__mindMapController.storeCommand(command)
 
     def _startTransport(self, userJid, password, host, port):
         '''
@@ -487,7 +475,7 @@ class NetworkController(QObject):
         if self.__isServiceRole and changeset.type != 'command':
             return
         executeChangeset = {'mindmap': 'loadMindMapFromNetwork',
-                'command': 'executeCommandFromNetwork',
+                'command': 'performCommandFromNetwork',
                 'undostack': 'loadUndoStackFromNetwork'}
         getattr(self.__mindMapController, executeChangeset[changeset.type])(changeset.data)
 
@@ -802,9 +790,9 @@ class HivemindXMPPClientConnector(SRVConnector):
     Hivemind implementation of XMPP connector
     @author: Oleg Kandaurov
     '''
-    def __init__(self, reactor, domain, port, factory):
+    def __init__(self, reactorInstance, domain, port, factory):
         '''Constructor'''
-        SRVConnector.__init__(self, reactor, 'xmpp-client', domain, factory)
+        SRVConnector.__init__(self, reactorInstance, 'xmpp-client', domain, factory)
         self.__port = port
 
     def pickServer(self):
@@ -1593,3 +1581,16 @@ def startReactor():
     reactor.addSystemEventTrigger('after', 'shutdown', reactor.qApp.quit)
     # stop twisted event loop when last window is closed
     reactor.qApp.lastWindowClosed.connect(reactor.stop)
+
+def _isPropagationAllowed(command):
+    '''
+    Check if command must be propagated through network or not
+    @param command: command to inspect
+    '''
+    if hivemind.settings.get('presentationMode'):
+        return True
+    if isinstance(command, StateModificationCommand) and command.isFoldCommand():
+        return False
+    if isinstance(command, CurrentNodeCommand):
+        return False
+    return True
